@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 99 $
+# Revision: $Rev: 117 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -71,10 +71,14 @@ class ListViewRecord(QListView):
         self.obj = None           # keeps track of the last item added
         self.items = {}                 # maps ListViewItem -> record
 
+        # normal search
+        self.wrappedSearch = False
+        self.firstSearch = True
+
         # incremental search string
         self.incSearch = ""
         self.incSearchHistory = []
-        self.wrappedSearch = False
+        self.incWrappedSearch = False
         self.searchOffTimer = QTimer()
 
         # connect signals
@@ -96,6 +100,7 @@ class ListViewRecord(QListView):
         """returns an unsorted list of all records"""
         return self.items.values()
 
+
     def __len__(self):
         """returns number of elements in the list view"""
         return len(self.items.keys())
@@ -129,6 +134,101 @@ class ListViewRecord(QListView):
         self.onModified()
 
 
+    def findNext(self, text, field, options):
+        """continues search for a text in a specific field"""
+        # wether to clear search status
+        if (text is None):
+            self.log.debug("Clearing search status")
+            self.firstSearch = True
+            return
+
+        self.log.info("Searching for %s in %s", text, field or "<all fields>")
+
+        # runtime variables
+        allFieldKeys = ('mediaLabel', 'source', 'borrower', 'originalTitle',
+                        'translatedTitle', 'director', 'producer', 'country',
+                        'category', 'actors', 'description', 'comments',
+                        'languages', 'subtitles', 'year')
+        keyFound = None
+        found = False
+        visited = dict()
+        obj = self.currentItem()        # start at current item
+        
+        # on first time use current item as starting point
+        if (not self.firstSearch):
+            if (options['searchForward']): obj = obj.itemBelow()
+            else: obj = obj.itemAbove()
+        self.firstSearch = False
+
+        # considder case-sensitivity
+        if (not options['caseSensitive']):
+            text = text.lower()
+
+        while (not found):
+            # on wrap over
+            if (self.wrappedSearch):
+                self.log.info("Continuing wrapped search")
+                self.wrappedSearch = False
+                if (options['searchForward']):
+                    obj = self.firstChild()
+                else:
+                    obj = self.lastItem()
+                    
+            # at end of page (top or bottom)
+            if (obj == None):
+                QApplication.beep()
+
+                # if all items have been searched
+                if (len(visited.keys()) == len(self.items.keys())): break
+
+                if (options['searchForward']):
+                    self.log.info("Continue search at the top?")
+                    self.emit(PYSIGNAL("searchTextChanged"), ("Continue search at the top?",))
+                else:
+                    self.log.info("Continue search at the bottom?")
+                    self.emit(PYSIGNAL("searchTextChanged"), ("Continue search at the bottom?",))
+                self.wrappedSearch = True
+                return
+
+            # search in all fields
+            rec = self.items[obj]            
+            if (field == None):
+                for k in allFieldKeys:
+                    keyFound = k
+                    value = unicode(rec[k])
+                    if (not options['caseSensitive']):
+                        value = value.lower()
+                    found = (value.find(text) != -1)
+                    if (found): break
+            # search in given field
+            else:
+                assert(rec.has_key(field))
+                value = rec[field]
+                if (not options['caseSensitive']):
+                    value = value.lower()
+                found = (value.find(text) != -1)
+
+            # add object to visited items
+            visited[obj] = 1
+
+            # move on in direction
+            if (not found):
+                if (options['searchForward']): obj = obj.itemBelow()
+                else: obj = obj.itemAbove()
+
+        # focus on found object
+        if (found):
+            self.log.debug("Found match at %d in field %s", rec['number'], keyFound or field)
+            self.emit(PYSIGNAL("searchTextChanged"), ("Found match at %d in field %s"%(rec['number'], keyFound or field),))
+            self.focus(obj)
+        # error if not found
+        else:
+            self.log.info("No match found")
+            self.emit(PYSIGNAL("searchTextChanged"), ("No match found",))
+            
+            
+
+
     def focusFirst(self):
         """sets focus on the first record in the listview"""
         self.focus(self.firstChild())
@@ -139,7 +239,6 @@ class ListViewRecord(QListView):
         self.focus(self.obj)
     
 
-    #-- helper functions -------------------------------------------------------
     def focus(self, obj):
         """sets focus on one particular object"""
         if (obj != None):
@@ -149,6 +248,7 @@ class ListViewRecord(QListView):
         self.setFocus()
           
 
+    #-- helper functions -------------------------------------------------------
     def compileTitles(self, record):
         """return a text-tuple what forms the ListViewItem entries """
         num = unicode(record['number'])
@@ -186,11 +286,11 @@ class ListViewRecord(QListView):
     def onSearchTimeout(self):
         """called when timeout on incremental search"""
         self.searchOffTimer.stop()      # stop running timer
-        self.emit(PYSIGNAL("incSearchTextChanged"), ("Stopping incremental search",))
+        self.emit(PYSIGNAL("searchTextChanged"), ("Stopping incremental search",))
         self.log.debug("Clearing incremental search history")
         self.incSearch = ""
         self.incSearchHistory = []
-        self.wrappedSearch = False
+        self.incWrappedSearch = False
       
 
     def keyPressEvent(self, e):
@@ -208,12 +308,12 @@ class ListViewRecord(QListView):
         if (e.key() == QListView.Key_Backspace):
             if (len(self.incSearchHistory) > 0):
                 (self.incSearch, prevItem) = self.incSearchHistory.pop()
-                self.emit(PYSIGNAL("incSearchTextChanged"), ("Text found: \"%s\""%self.incSearch,))
+                self.emit(PYSIGNAL("searchTextChanged"), ("Text found: \"%s\""%self.incSearch,))
                 self.setCurrentItem( prevItem )
                 self.ensureItemVisible( prevItem )
             else:
                 QApplication.beep()
-                self.emit(PYSIGNAL("incSearchTextChanged"), ("Search text empty",))
+                self.emit(PYSIGNAL("searchTextChanged"), ("Search text empty",))
             return
 
         # abort on escape
@@ -239,15 +339,15 @@ class ListViewRecord(QListView):
                 return
             
             # rollover
-            if (not self.wrappedSearch and
+            if (not self.incWrappedSearch and
                 ((self.itemPos(nextItem) < self.itemPos(currItem)) or (currItem == self.lastItem()))):
                 self.setCurrentItem(currItem)
-                self.wrappedSearch = True
-                self.emit(PYSIGNAL("incSearchTextChanged"), ("End of list: wrap over?",))
+                self.incWrappedSearch = True
+                self.emit(PYSIGNAL("searchTextChanged"), ("End of list: wrap over?",))
                 QApplication.beep()
                 return
-            elif (self.wrappedSearch):
-                self.wrappedSearch = False
+            elif (self.incWrappedSearch):
+                self.incWrappedSearch = False
                 self.setCurrentItem(self.firstChild())
 
         else:
@@ -258,12 +358,12 @@ class ListViewRecord(QListView):
             
         # text does not match
         if (item == None):
-            self.emit(PYSIGNAL("incSearchTextChanged"), ("Text not found: \"%s\""%self.incSearch,))
+            self.emit(PYSIGNAL("searchTextChanged"), ("Text not found: \"%s\""%self.incSearch,))
             QApplication.beep()
             self.log.info("No match for \"%s\"", self.incSearch)
         # match found
         else:
-            self.emit(PYSIGNAL("incSearchTextChanged"), ("Text found: \"%s\""%self.incSearch,))
+            self.emit(PYSIGNAL("searchTextChanged"), ("Text found: \"%s\""%self.incSearch,))
             self.setCurrentItem(item)
             self.ensureItemVisible(item)
     
