@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 97 $
+# Revision: $Rev: 114 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -88,6 +88,7 @@ class RecordList(RecordListBase):
         imageLayout.addWidget( self.image, 0,0 )
 
         self.connect( self.listViewRecord, SIGNAL("currentChanged(QListViewItem*)"), self.onCurrentChanged )
+        self.connect( self.listViewRecord, PYSIGNAL("searchTextChanged"), PYSIGNAL("searchTextChanged"))
         self.connect( self.form, PYSIGNAL("modified()"), self.listViewRecord.onModified )    
         # currently not needed: 
         # self.connect( self.image, PYSIGNAL("modified()"), self.onModified )
@@ -129,6 +130,10 @@ class RecordList(RecordListBase):
         self.image.setRecord(record)
 
 
+    def findNext(self, text, field, options):
+        self.listViewRecord.findNext(text, field, options)
+
+
     #-- observer ---------------------------------------------------------------
     def onCurrentChanged(self, obj):
         """called when the \"current\" item changes"""
@@ -151,7 +156,10 @@ class RecordList(RecordListBase):
         """displays the last item added"""
         self.listViewRecord.focusNew()
 
-        
+
+    def focus(self, obj):
+        """displays the selected object"""
+        self.listViewRecord.focus(obj)
     
 
 #-- testroutine ----------------------------------------------------------------
