@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 105 $
+# Revision: $Rev: 109 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -35,7 +35,7 @@ from pprint import pformat
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 105 $
+# Revision: $Rev: 109 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -111,6 +111,13 @@ logLevel = %(logLevel)s
 defaultPath = %(defaultPath)s
 
 
+# defaultMoviePath defines the path which lmc uses as its first entry
+# point when getting information from files
+# The default is the current working directory.
+
+defaultMoviePath = %(defaultMoviePath)s
+
+
 # browserPath is the path to the executable of your prefered internet
 # browser. This is the program executed to load external HTML pages.
 # The default is '/usr/bin/mozilla'.
@@ -371,6 +378,7 @@ class _Settings0(dict):
                      },
 
         'defaultPath': os.environ['PWD'],
+        'defaultMoviePath': os.environ['PWD'],
         'browserPath': '/usr/bin/mozilla',
 
         'defaultHistory': {'subtitles'       : ('English', 'German'),
@@ -426,7 +434,7 @@ class _Settings0(dict):
         'mediaInfo': None,
         'autoMountPoint': None,
         'ejectOnUnmount': True,
-        'autoScanAutoMountOnNew': True,
+        'autoScanAutoMountOnNew': False,
         'autoScanOnNew': False,
         'autoScriptOnNew': False,
         
@@ -481,7 +489,7 @@ class _Settings0(dict):
                                      "import MediaInfo"])}
 
         # general fields
-        for key in ['logLevel', 'defaultPath', 'browserPath',
+        for key in ['logLevel', 'defaultPath', 'defaultMoviePath', 'browserPath',
                     'proxy', 'systemEncoding', 'recordStoreOrderRandom',
                     'embeddedImage', 'imageFormat', 'filenamePrefix', 'sortColumn',
                     'zeroPrefix_patch', 'scripts', 'defaultScript', 'autoMountPoint',
@@ -595,7 +603,7 @@ class _Pref(dict):
         """updates the own contents, given a template"""
         self.clear()
         # update simple values
-        for key in ['defaultPath', 'browserPath', 'proxy',
+        for key in ['defaultPath', 'defaultMoviePath', 'browserPath', 'proxy',
                     'systemEncoding', 'recordStoreOrderRandom', 'mediaInfo',
                     'embeddedImage', 'imageFormat', 'filenamePrefix',
                     'sortColumn', 'zeroPrefix_patch', 'scripts',
