@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 105 $
+# Revision: $Rev: 114 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -25,7 +25,8 @@
 #-- imports --------------------------------------------------------------------
 #-- Qt imports --
 from qt import QApplication, QObject, SLOT, SIGNAL, QProcess, QDir, PYSIGNAL
-from qt import QFileDialog, QMessageBox, QInputDialog, QLineEdit
+from qt import QFileDialog, QMessageBox, QInputDialog, QLineEdit, QPopupMenu
+from qt import QIconSet
 
 #-- Python imports --
 import sys
@@ -35,7 +36,7 @@ import time
 
 from types import ListType
 from os.path import dirname, basename, exists as fexists, samefile, \
-     getsize as fsize, splitext, join
+     getsize as fsize, splitext, join as fjoin
 from copy import deepcopy
 
 #-- own imports --
@@ -53,6 +54,7 @@ from RecordPreview import RecordPreview
 from ScriptExecDialog import ScriptExecDialog
 from ScriptSelection import ScriptSelection
 from StdIOProcess import StdIOProcess
+from FindDialog import FindDialog
 
 
 #-- create logging and load preferences ----------------------------------------
@@ -64,7 +66,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 105 $ (c) by Uwe Mayer")
+log.info("lmc.py - LMC Movie Catalogue  $Rev: 114 $ (c) by Uwe Mayer")
 
 # load settings
 settings = Settings.Settings()
@@ -106,7 +108,7 @@ fileFilterList = filter(lambda a: a != "", map(lambda a: a[1], fileFormats))
 
 
 #-- utility functions ----------------------------------------------------------
-defaultCaption = "LMC Movie Catalogue ($Rev: 105 $) "
+defaultCaption = "Moviefly ($Rev: 114 $) "
 filenameCaption = lambda a: defaultCaption+" - %s"%basename(a)
 
 
@@ -122,10 +124,20 @@ class LMCMain(LMCWidgetBase):
         except IOError, e:
             pass                        # TODO: do abort
 
+        # scan from file popup menu
+        self.movieGetLocalPopup = QPopupMenu(self)
+        self.movieGetLocalPopup.insertItem(QIconSet(self.image13), self.tr("from files..."), self.movieGetLocalFromFiles)
+        self.movieGetLocalPopup.insertItem(QIconSet(self.image31), self.tr("from files on CD..."), self.movieGetLocalCDFromFiles)
+        # disable actions
+        self.movieGetLocalPopup.setItemEnabled(self.movieGetLocalPopup.idAt(0), True)
+        self.movieGetLocalPopup.setItemEnabled(self.movieGetLocalPopup.idAt(1), False)
+        # add popup menu
+        self.toolGetFromFilesAction.setPopup(self.movieGetLocalPopup)
 
         # runtime variables
         self.__file = None              # no file opened so far
         self.lastFolder = pref['defaultPath']
+        self.lastMovieFolder = pref['defaultMoviePath']
         self.recordCopy = None
         self.modified = False           # modified metadata or deleted record
         
@@ -152,6 +164,11 @@ class LMCMain(LMCWidgetBase):
         self.statusBar().message(message, delay)
 
 
+    def infoStatusBar(self, message, delay=1000):
+        """displays short message in status bar"""
+        self.statusBar().message(message, delay)
+
+
     def closeEvent(self, e):
         """called when application is closed: checks if file needs saving"""
         if (self.__file != None):
@@ -167,7 +184,8 @@ class LMCMain(LMCWidgetBase):
         if (len(self.centralWidget()) != 0): self.__disableMovieDeleteAction()
 
         self.__querySaveOnDirty()
-      
+
+        self.infoStatusBar("Closing file %s"%basename(self.__file.name))
         self.centralWidget().hide()
         self.setCentralWidget(None)
         self.__file.close()
@@ -192,6 +210,7 @@ class LMCMain(LMCWidgetBase):
             return
 
         self.log.info("Saving file %s", basename(self.__file.name))
+        self.infoStatusBar("Saving file %s"%(basename(self.__file.name)))
         self.__file.truncate(0)
         # sort records ascendingly on 'number'
         records = self.centralWidget().values()
@@ -231,6 +250,7 @@ class LMCMain(LMCWidgetBase):
             if (ans == QMessageBox.No): return           
 
         # finally save file
+        self.infoStatusBar("Saving as new file %s"%basename(filename))
         try:
             # create new file
             f = cls(filename, "wb")
@@ -283,6 +303,7 @@ class LMCMain(LMCWidgetBase):
             if (ans == QMessageBox.No): return
 
         # try opening read-write access
+        self.infoStatusBar("Creating new file %s"%basename(filename))
         try: 
             f = cls(filename, "w+b")
         except IOError, e:
@@ -325,6 +346,7 @@ class LMCMain(LMCWidgetBase):
         filename = unicode(dlg.selectedFile())
 
         # autoprobe file formats (they raise TypeError on mismatch)
+        self.infoStatusBar("Opening file %s"%basename(filename))
         f = None
         for (cls, _, _) in fileFormats:
             self.log.debug("Autoprobing file format")
@@ -360,7 +382,7 @@ class LMCMain(LMCWidgetBase):
             
         # now remember newly opened file
         self.lastFolder = dirname(filename) # remember last folder
-        self.log.info("opening file %s (size: %d)", basename(filename), fsize(filename))
+        self.log.info("Opening file %s (size: %d)", basename(filename), fsize(filename))
         self.__file = f
 
         # set caption
@@ -392,6 +414,7 @@ class LMCMain(LMCWidgetBase):
             else: break
 
         # append empty record
+        self.infoStatusBar("Adding new record %d"%index)
         dateVal = YMD2Date(*time.localtime()[0:3])
         self.log.debug("adding new record at index %d", index)
         new = deepcopy(pref['recordDefault'])
@@ -410,7 +433,10 @@ class LMCMain(LMCWidgetBase):
             self.movieGetLocalFromFiles()
         # do autoScanAutoMountOnNew
         if (pref['autoScanAutoMountOnNew']):
-            self.movieGetLocalCDFromFiles()
+            if (pref['autoMountPoint'] == None):
+                self.log.warning("Cannot auto-mount removeable device: none specified")
+            else:
+                self.movieGetLocalCDFromFiles()
         # do autoScriptOnNew
         if (pref['autoScriptOnNew']):
             self.movieGetLocalFromScript()
@@ -418,6 +444,8 @@ class LMCMain(LMCWidgetBase):
 
     def movieDelete(self):
         """deletes a record"""
+        record = self.centralWidget().getCurrentRecord()
+        self.infoStatusBar("Deleting record %d"%record['number'])
         del self.centralWidget()[self.centralWidget().listViewRecord.currentItem()]
 
         self.modified = True
@@ -430,7 +458,7 @@ class LMCMain(LMCWidgetBase):
         """get information from a file"""
         # select filenames
         filenames = QFileDialog.getOpenFileNames(
-            ";;".join(movieFileFilter), self.lastFolder, self,
+            ";;".join(movieFileFilter), self.lastMovieFolder, self,
             "scan file dialog", "Select file to scan")
         if (filenames == None): return
         filenames = map(lambda a: unicode(a.ascii(), pref['systemEncoding']), filenames)
@@ -439,10 +467,11 @@ class LMCMain(LMCWidgetBase):
         if (len(filenames) == 0): return
 
         # remember last directory
-        self.lastFolder = dirname(filenames[0])
+        self.lastMovieFolder = dirname(filenames[0])
 
         # get media info
-        self.log.info("getting file information for %s using %s", basename(filenames[0]), pref['mediaInfo'])
+        self.log.info("Getting file information for %s using %s", basename(filenames[0]), pref['mediaInfo'])
+        self.infoStatusBar("Getting file information from %s"%basename(filename))
         info = pref['mediaInfo'](filenames[0])
         info.scan()
 
@@ -482,13 +511,13 @@ class LMCMain(LMCWidgetBase):
         os.system("mount %s"%pref['autoMountPoint'])
         
         # remember usual default target path
-        tmp = self.lastFolder
-        self.lastFolder = pref['autoMountPoint']
+        tmp = self.lastMovieFolder
+        self.lastMovieFolder = pref['autoMountPoint']
         # get info
         self.movieGetLocalFromFiles()
                
         # restore target path
-        self.lastFolder = tmp
+        self.lastMovieFolder = tmp
 
         # unmount or eject
         if (pref['ejectOnUnmount']):
@@ -535,11 +564,12 @@ class LMCMain(LMCWidgetBase):
 
         # get details on all scripts
         summary = ""
+        self.infoStatusBar("Getting information from script on %s"%searchTitle)
         for script in scriptList:
             self.log.info("Getting title list from %s", script[0])
 
             # execute script for title matches
-            titleSearch = StdIOProcess(script[0], [searchTitle.encode(pref['systemEncoding'])], scriptProxy, scriptdir)
+            titleSearch = StdIOProcess(fjoin(".",script[0]), [searchTitle.encode(pref['systemEncoding'])], scriptProxy, scriptdir)
             execDlg = ScriptExecDialog(titleSearch, modal=True)
 
             # if process was aborted, stop
@@ -579,7 +609,7 @@ class LMCMain(LMCWidgetBase):
                 url = titleMatchDlg.selectedItem()
 
                 # fetch details
-                detailSearch = StdIOProcess(script[0], [url.encode(pref['systemEncoding'])], scriptProxy, scriptdir)
+                detailSearch = StdIOProcess(fjoin(".",script[0]), [url.encode(pref['systemEncoding'])], scriptProxy, scriptdir)
                 execDlg2 = ScriptExecDialog(detailSearch, modal=True)
                 
                 # if process was aborted, stop
@@ -625,22 +655,22 @@ class LMCMain(LMCWidgetBase):
         self.centralWidget().form.focus("mediaLabel")
         
 
-    def onMovieCopy(self):
+    def movieCopy(self):
         """copy current record"""
         record = self.centralWidget().getCurrentRecord()
         self.log.info("Copying record %s to clipboard", unicode(record['number']))
-        self.statusBar().message("Copying record %s to clipboard"%unicode(record['number']), 2000)
+        self.infoStatusBar("Copying record %s to clipboard"%unicode(record['number']))
         self.recordCopy = record        # copy reference to original
 
         if (not self.moviePasteAction.isEnabled()):
-            self.connect(self.moviePasteAction, SIGNAL("activated()"), self.onMoviePaste)
+            self.connect(self.moviePasteAction, SIGNAL("activated()"), self.moviePaste)
             self.moviePasteAction.setEnabled(True)
 
-            self.connect(self.toolPasteAction, SIGNAL("pressed()"), self.onMoviePaste)
+            self.connect(self.toolPasteAction, SIGNAL("pressed()"), self.moviePaste)
             self.toolPasteAction.setEnabled(True)
         
 
-    def onMoviePaste(self):
+    def moviePaste(self):
         """paste over current record"""
         record = self.centralWidget().getCurrentRecord()
 
@@ -655,7 +685,7 @@ class LMCMain(LMCWidgetBase):
             pref['autoScanOnNew'], pref['autoScanAutoMountOnNew'], pref['autoScriptOnNew'] = a, b, c
         
         self.log.info("Pasting to record %s from clipboard", unicode(record['number']))
-        self.statusBar().message("Pasting to record %s from clipboard"%unicode(record['number']), 2000)
+        self.infoStatusBar("Pasting to record %s from clipboard"%unicode(record['number']), 2000)
 
         originalNumber = record['number']
         record.update(deepcopy(self.recordCopy))
@@ -668,6 +698,22 @@ class LMCMain(LMCWidgetBase):
             self.centralWidget().image.imageDecode()
             
 
+    def movieFind(self):
+        """find a movie according to field value"""
+
+        def findNext(text, field, options):
+#            self.updateStatusBar("Searching for %s in field %s"%(text, field))
+            self.centralWidget().findNext(text, field, options)
+            
+        findDlg = FindDialog(self)
+        self.connect(findDlg, PYSIGNAL("findValue"), findNext)
+        findDlg.exec_loop()
+        findNext(None, None, None)
+        self.disconnect(findDlg, PYSIGNAL("findValue"), findNext)
+
+
+        
+
     #-- helper methods ---------------------------------------------------------
     def __querySaveOnDirty(self):
         """asks user wether to save file when there are dirty records"""
@@ -769,10 +815,10 @@ class LMCMain(LMCWidgetBase):
             self.recordCopy = None
             
             self.moviePasteAction.setEnabled(False)
-            self.disconnect(self.moviePasteAction, SIGNAL("activated()"), self.onMoviePaste)
+            self.disconnect(self.moviePasteAction, SIGNAL("activated()"), self.moviePaste)
 
             self.toolPasteAction.setEnabled(False)
-            self.disconnect(self.toolPasteAction, SIGNAL("pressed()"), self.onMoviePaste)
+            self.disconnect(self.toolPasteAction, SIGNAL("pressed()"), self.moviePaste)
 
 
     def __enableMovieDeleteAction(self):
@@ -785,16 +831,16 @@ class LMCMain(LMCWidgetBase):
 
         self.connect(self.movieGetLocalFromFilesAction, SIGNAL("activated()"), self.movieGetLocalFromFiles)
         self.movieGetLocalFromFilesAction.setEnabled(True)
-        
-        self.connect(self.toolGetFromFilesAction, SIGNAL("pressed()"), self.movieGetLocalFromFiles)
+
+        self.connect(self.toolGetFromFilesAction, SIGNAL("clicked()"), self.movieGetLocalFromFiles)
         self.toolGetFromFilesAction.setEnabled(True)
 
         if (pref['autoMountPoint'] != None):
             self.connect(self.movieGetLocalCDFromFilesAction, SIGNAL("activated()"), self.movieGetLocalCDFromFiles)
             self.movieGetLocalCDFromFilesAction.setEnabled(True)
 
-            self.connect(self.toolGetCDFromFilesAction, SIGNAL("pressed()"), self.movieGetLocalCDFromFiles)
-            self.toolGetCDFromFilesAction.setEnabled(True)
+            self.movieGetLocalPopup.setItemEnabled(self.movieGetLocalPopup.idAt(1), True)
+
 
         self.connect(self.movieGetLocalFromScriptAction, SIGNAL("activated()"), self.movieGetLocalFromScript)
         self.movieGetLocalFromScriptAction.setEnabled(True)
@@ -802,14 +848,20 @@ class LMCMain(LMCWidgetBase):
         self.connect(self.toolGetFromScriptAction, SIGNAL("pressed()"), self.movieGetLocalFromScript)
         self.toolGetFromScriptAction.setEnabled(True)
 
-        self.connect(self.centralWidget().listViewRecord, PYSIGNAL("incSearchTextChanged"), self.updateStatusBar)
+        self.connect(self.centralWidget(), PYSIGNAL("searchTextChanged"), self.updateStatusBar)
 
-        self.connect(self.movieCopyAction, SIGNAL("activated()"), self.onMovieCopy)
+        self.connect(self.movieCopyAction, SIGNAL("activated()"), self.movieCopy)
         self.movieCopyAction.setEnabled(True)
 
-        self.connect(self.toolCopyAction, SIGNAL("pressed()"), self.onMovieCopy)
+        self.connect(self.toolCopyAction, SIGNAL("pressed()"), self.movieCopy)
         self.toolCopyAction.setEnabled(True)
 
+        self.connect(self.movieFindAction, SIGNAL("activated()"), self.movieFind)
+        self.movieFindAction.setEnabled(True)
+
+        self.connect(self.toolFindAction, SIGNAL("pressed()"), self.movieFind)
+        self.toolFindAction.setEnabled(True)
+
 
     def __disableMovieDeleteAction(self):
         """disables actions related to deleting a record"""
@@ -823,14 +875,13 @@ class LMCMain(LMCWidgetBase):
         self.disconnect(self.movieGetLocalFromFilesAction, SIGNAL("activated()"), self.movieGetLocalFromFiles)
 
         self.toolGetFromFilesAction.setEnabled(False)
-        self.disconnect(self.toolGetFromFilesAction, SIGNAL("pressed()"), self.movieGetLocalFromFiles)
+        self.disconnect(self.toolGetFromFilesAction, SIGNAL("clicked()"), self.movieGetLocalFromFiles)
 
         if (pref['autoMountPoint'] != None):
             self.movieGetLocalCDFromFilesAction.setEnabled(False)
             self.disconnect(self.movieGetLocalCDFromFilesAction, SIGNAL("activated()"), self.movieGetLocalCDFromFiles)
             
-            self.toolGetCDFromFilesAction.setEnabled(False)
-            self.disconnect(self.toolGetCDFromFilesAction, SIGNAL("pressed()"), self.movieGetLocalCDFromFiles)
+            self.movieGetLocalPopup.setItemEnabled(self.movieGetLocalPopup.idAt(1), False)
 
         self.movieGetLocalFromScriptAction.setEnabled(False)
         self.disconnect(self.movieGetLocalFromScriptAction, SIGNAL("activated()"), self.movieGetLocalFromScript)
@@ -838,14 +889,19 @@ class LMCMain(LMCWidgetBase):
         self.toolGetFromScriptAction.setEnabled(False)
         self.disconnect(self.toolGetFromScriptAction, SIGNAL("pressed()"), self.movieGetLocalFromScript)
 
-        self.disconnect(self.centralWidget().listViewRecord, PYSIGNAL("incSearchTextChanged"), self.updateStatusBar)
+        self.disconnect(self.centralWidget(), PYSIGNAL("searchTextChanged"), self.updateStatusBar)
 
         self.movieCopyAction.setEnabled(False)
-        self.disconnect(self.movieCopyAction, SIGNAL("activated()"), self.onMovieCopy)
+        self.disconnect(self.movieCopyAction, SIGNAL("activated()"), self.movieCopy)
 
         self.toolCopyAction.setEnabled(False)
-        self.disconnect(self.toolCopyAction, SIGNAL("pressed()"), self.onMovieCopy)
+        self.disconnect(self.toolCopyAction, SIGNAL("pressed()"), self.movieCopy)
 
+        self.movieFindAction.setEnabled(False)
+        self.disconnect(self.movieFindAction, SIGNAL("activated()"), self.movieFind)
+
+        self.toolFindAction.setEnabled(False)
+        self.disconnect(self.toolFindAction, SIGNAL("pressed()"), self.movieFind)
         
         
 
