@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # Author:   $Author: merkosh $
-# Revision: $Rev: 88 $
+# Revision: $Rev: 98 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -31,6 +31,7 @@ use LWP::UserAgent;
 use HTTP::Request;
 use HTML::Entities;
 use File::Basename;
+use POSIX qw(ceil);
 
 use LMCTools;
 
@@ -239,7 +240,7 @@ if ($URL){
   # if no rating available (first 100 char contain magic text)
   if (substr($tmp, 0, 100) !~ /awaiting \d votes/) {
     $tmp = &find($tmp, '<b>');
-    $data{rating} = $1 if ($tmp =~ /([\d\.]+)/);
+    $data{rating} = ceil($1) if ($tmp =~ /([\d\.]+)/);
   }
 
   # url
